==> huaweicloudsdkgsl-3.1.76-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/enable_attribute_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EnableAttributeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'attribute_id': 'int'
    }

    attribute_map = {
        'attribute_id': 'attribute_id'
    }

    def __init__(self, attribute_id=None):
        """EnableAttributeRequest

        The model defined in huaweicloud sdk

        :param attribute_id: 自定义属性标识
        :type attribute_id: int
        """
        
        

        self._attribute_id = None
        self.discriminator = None

        self.attribute_id = attribute_id

    @property
    def attribute_id(self):
        """Gets the attribute_id of this EnableAttributeRequest.

        自定义属性标识

        :return: The attribute_id of this EnableAttributeRequest.
        :rtype: int
        """
        return self._attribute_id

    @attribute_id.setter
    def attribute_id(self, attribute_id):
        """Sets the attribute_id of this EnableAttributeRequest.

        自定义属性标识

        :param attribute_id: The attribute_id of this EnableAttributeRequest.
        :type attribute_id: int
        """
        self._attribute_id = attribute_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableAttributeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgsl-3.1.153-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/enable_attribute_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EnableAttributeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'attribute_id': 'int'
    }

    attribute_map = {
        'attribute_id': 'attribute_id'
    }

    def __init__(self, attribute_id=None):
        r"""EnableAttributeRequest

        The model defined in huaweicloud sdk

        :param attribute_id: 自定义属性标识
        :type attribute_id: int
        """
        
        

        self._attribute_id = None
        self.discriminator = None

        self.attribute_id = attribute_id

    @property
    def attribute_id(self):
        r"""Gets the attribute_id of this EnableAttributeRequest.

        自定义属性标识

        :return: The attribute_id of this EnableAttributeRequest.
        :rtype: int
        """
        return self._attribute_id

    @attribute_id.setter
    def attribute_id(self, attribute_id):
        r"""Sets the attribute_id of this EnableAttributeRequest.

        自定义属性标识

        :param attribute_id: The attribute_id of this EnableAttributeRequest.
        :type attribute_id: int
        """
        self._attribute_id = attribute_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableAttributeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
